# Setup python target for shiboken so the right cmake file is imported.
%global py_suffix %(%{__python3} -c "import sysconfig; print(sysconfig.get_config_var('SOABI'))")

# Commit hash should be updated manually at each release,
# it's included in the build version.
%define renderdoc_hash 35b13a8e8fd2a331854dba6da81a20452e142d6f
%define swig_version renderdoc-modified-7

Name:           renderdoc
Version:        1.27
Release:        %mkrel 1
Summary:        Stand-alone graphics API debugging tool for Vulkan and OpenGL
Group:          Development/Tools
License:        MIT
URL:            https://renderdoc.org
Source0:        https://github.com/baldurk/renderdoc/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/baldurk/swig/archive/%{swig_version}/swig-%{swig_version}.tar.gz

# (akien) plthook embedded library does not support ARM (as of June 2017)
# and upstream considers ARM support is not needed for this package
# (daviddavid) upstream says that only x86-64 is supported on linux
# "x86-64 is the only architecture that I officially support on linux"
# https://github.com/baldurk/renderdoc/issues/1991
ExclusiveArch:  x86_64

BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  pyside2-tools
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(pyside2)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-keysyms)


%description
RenderDoc is a free MIT licensed stand-alone graphics debugger that allows
quick and easy single-frame capture and detailed introspection of any
application using Vulkan, D3D11, OpenGL or D3D12 across Windows 7-10, Linux
or Android.

%prep
%autosetup -p1

%build
%cmake \
  -DBUILD_VERSION_HASH="%{renderdoc_hash}" \
  -DBUILD_VERSION_DIST_NAME="%{_vendor}" \
  -DBUILD_VERSION_DIST_VER="%{version}-%{release}" \
  -DBUILD_VERSION_DIST_CONTACT="https://madb.mageia.org/package/show/name/renderdoc" \
  -DBUILD_VERSION_STABLE=ON \
  -DRENDERDOC_SWIG_PACKAGE="%{SOURCE1}" \
  -DPYSIDE2_PACKAGE_INIT_PY=%{python3_sitearch}/
%cmake_build

%install
%cmake_install

# Debian-specific
rm -rf %{buildroot}%{_datadir}/menu

%files
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}cmd
%{_bindir}/q%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}-capture.xml
%{_datadir}/pixmaps/%{name}-icon-{16x16,32x32}.xpm
%{_datadir}/thumbnailers/%{name}.thumbnailer
%{_iconsdir}/hicolor/scalable/mimetypes/application-x-%{name}-capture.svg
%{_includedir}/%{name}_app.h
%{_libdir}/lib%{name}.so
%{_sysconfdir}/vulkan/implicit_layer.d/%{name}_capture.json


%changelog
* Sun Jul 02 2023 daviddavid <daviddavid> 1.27-1.mga9
+ Revision: 1963493
- new version: 1.27, fixes CVE-2023-3386[3-5] (mga#32010)
- not yet ready for pcre2
- switch to pcre2

* Thu Feb 02 2023 akien <akien> 1.25-1.mga9
+ Revision: 1937576
- Version 1.25

* Fri Dec 02 2022 akien <akien> 1.23-1.mga9
+ Revision: 1914033
- Version 1.23

* Sat Nov 19 2022 papoteur <papoteur> 1.18-3.mga9
+ Revision: 1908765
- fix BR, adding pcre

* Wed Apr 06 2022 umeabot <umeabot> 1.18-2.mga9
+ Revision: 1846079
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 akien <akien> 1.18-1.mga9
+ Revision: 1779169
- Version 1.18

* Sat Mar 20 2021 daviddavid <daviddavid> 1.12-2.mga9
+ Revision: 1705559
- rebuild for python 3.9

* Wed Jan 27 2021 akien <akien> 1.12-1.mga8
+ Revision: 1673764
- Version 1.12

* Thu Dec 17 2020 akien <akien> 1.11-1.mga8
+ Revision: 1660148
- Version 1.11

* Thu Dec 17 2020 umeabot <umeabot> 1.10-2.mga8
+ Revision: 1659725
- Rebuild for new Qt5

* Fri Oct 23 2020 akien <akien> 1.10-1.mga8
+ Revision: 1638897
- Version 1.10

* Tue Jul 28 2020 daviddavid <daviddavid> 1.9-3.mga8
+ Revision: 1609343
- really enable PySide2 support

* Mon Jul 27 2020 daviddavid <daviddavid> 1.9-2.mga8
+ Revision: 1609251
- enable PySide2 support

* Sat Jul 25 2020 daviddavid <daviddavid> 1.9-1.mga8
+ Revision: 1608957
- new version: 1.9
- only x86-64 is supported on linux
  * https://github.com/baldurk/renderdoc/issues/1991

* Wed Mar 25 2020 akien <akien> 1.7-1.mga8
+ Revision: 1559960
- version 1.7

* Thu Feb 20 2020 umeabot <umeabot> 1.6-2.mga8
+ Revision: 1547262
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 daviddavid <daviddavid> 1.6-1.mga8
+ Revision: 1487736
- new version: 1.6
+ wally <wally>
- build with new cmake macros
+ akien <akien>
- Version 1.5

* Tue Sep 17 2019 daviddavid <daviddavid> 1.4-3.mga8
+ Revision: 1442812
- rebuild for python3.8

* Tue Aug 27 2019 daviddavid <daviddavid> 1.4-2.mga8
+ Revision: 1433236
- add upstream patch to not use deprecated overload of QProcess::ExitStatus
- add upstream patch to add python 3.8 compatibility
- add patch to skip unrecognized command line option '-Wno-unknown-warning'

* Mon Apr 29 2019 akien <akien> 1.4-1.mga7
+ Revision: 1395921
- Version 1.4

* Mon Apr 01 2019 umeabot <umeabot> 1.2-3.mga7
+ Revision: 1384676
- Qt5 Rebuild

* Tue Jan 08 2019 tv <tv> 1.2-2.mga7
+ Revision: 1352363
- rebuild with python 3.7

* Thu Jan 03 2019 daviddavid <daviddavid> 1.2-1.mga7
+ Revision: 1348878
- new version: 1.2

* Mon Oct 01 2018 daviddavid <daviddavid> 1.1-1.mga7
+ Revision: 1314062
- new version: 1.1
- remove merged upstream patch
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri Mar 09 2018 akien <akien> 1.0-1.mga7
+ Revision: 1207590
- Version 1.0

* Sun Oct 15 2017 daviddavid <daviddavid> 0.91-1.mga7
+ Revision: 1172081
- new version: 0.91
- remove merged upstream patch
- use -DRENDERDOC_SWIG_PACKAGE for swig package
- do not package menu files (/usr/share/menu)

* Mon Aug 07 2017 daviddavid <daviddavid> 0.34-3.mga7
+ Revision: 1138427
- rebuild for new Python 3.6

* Sat Jun 10 2017 akien <akien> 0.34-2.mga6
+ Revision: 1107505
- Exclude ARM platforms, plthook dependency does not support them

* Fri Jun 09 2017 akien <akien> 0.34-1.mga6
+ Revision: 1107384
- Version 0.34 (bundles modified swig)

* Mon Apr 10 2017 akien <akien> 0.33-3.mga6
+ Revision: 1096232
- Fix version string in Qt UI

* Sun Apr 09 2017 akien <akien> 0.33-2.mga6
+ Revision: 1096223
- Fix library path in vulkan renderdoc_capture.json

* Sun Apr 09 2017 akien <akien> 0.33-1.mga6
+ Revision: 1096217
- imported package renderdoc

